@@ -40,7 +40,7 @@
                                      speed=TRUE))
         ## for postdive total distance and mean speed
         ptd <- matrix(c(pdtimes, getSpeed(zvtdr)[okpd]), ncol=2)
-        pdv <- do.call(rbind, by(ptd, pdids, .getSpeedStats))
+        pdv <- do.call(rbind, by(ptd, pdids, diveMove:::.getSpeedStats))
         res <- data.frame(perdive, postdive.dur, postdive.tdist=pdv[, 1],
                           postdive.mean.speed=pdv[, 2])
         for (i in 1:3) res[, i] <- structure(res[, i],
